Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1099)

Unified Diff: src/factory.h

Issue 237963024: Select function map based on prototype and shared function info. (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Addressed comment Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/factory.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/factory.h
diff --git a/src/factory.h b/src/factory.h
index d52e66e05f8fcd104604de901266b95d42d214f0..0c850613bb95b8c6df84f97d9a803bb3aed4377c 100644
--- a/src/factory.h
+++ b/src/factory.h
@@ -633,19 +633,19 @@ class Factory V8_FINAL {
Handle<AllocationSite> allocation_site);
// Initializes a function with a shared part and prototype.
// Note: this code was factored out of NewFunctionHelper such that
// other parts of the VM could use it. Specifically, a function that creates
// instances of type JS_FUNCTION_TYPE benefit from the use of this function.
inline void InitializeFunction(Handle<JSFunction> function,
- Handle<SharedFunctionInfo> shared,
- Handle<Object> prototype);
+ Handle<SharedFunctionInfo> info,
+ Handle<Context> context,
+ MaybeHandle<Object> maybe_prototype);
// Creates a function initialized with a shared part.
- inline Handle<JSFunction> NewFunctionHelper(
- Handle<Map> function_map,
- Handle<SharedFunctionInfo> shared,
- Handle<Object> prototype,
- PretenureFlag pretenure = TENURED);
+ inline Handle<JSFunction> NewFunction(Handle<SharedFunctionInfo> info,
+ Handle<Context> context,
+ MaybeHandle<Object> maybe_prototype,
+ PretenureFlag pretenure = TENURED);
// Create a new map cache.
Handle<MapCache> NewMapCache(int at_least_space_for);
« no previous file with comments | « no previous file | src/factory.cc » ('j') | no next file with comments »
@@ -633,19 +633,19 @@ class Factory V8_FINAL {
Handle<AllocationSite> allocation_site);
// Initializes a function with a shared part and prototype.
- // Note: this code was factored out of NewFunctionHelper such that
- // other parts of the VM could use it. Specifically, a function that creates
- // instances of type JS_FUNCTION_TYPE benefit from the use of this function.
+ // Note: this code was factored out of NewFunction such that other parts of
+ // the VM could use it. Specifically, a function that creates instances of
+ // type JS_FUNCTION_TYPE benefit from the use of this function.
inline void InitializeFunction(Handle<JSFunction> function,

Powered by Google App Engine
This is Rietveld 408576698